==> ejc-procurement-api-3.0.0-20251204.031530-36-sources.jar: com/ejianc/business/procurement/plan/vo/UnTenderMatterVO.java <==
package com.ejianc.business.procurement.plan.vo;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;

import java.math.BigDecimal;
import java.util.Date;


/**
 * 拟不招标事项申请表
 * 
 * @author generator
 * 
 */
public class UnTenderMatterVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private BigDecimal matterTaxMny; // 各标的预算
    private BigDecimal preTaxMny; // 预计合同总金额
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date makeDate; // 编制日期
    private String billCode; // 单据编号
    private String projectCode; // 项目编码
    private String projectName; // 项目名称
    private String orgName; // 项目部名称
    private String orgCode; // 项目部编码
    private String parentOrgName; // 项目部上级名称
    private String parentOrgCode; // 项目部上级编码
    private String allOrgName; // 所属组织(所属单位-项目经理部)
    private String employeeName; // 经办人名称
    private String tenderType; // 招标执行程序1-法定必招项目，2-一般招标项目
    private String purchaseMatter; // 采购标的
    private String unLegalBiddingName; // 拟邀请招标情形名称（法定必招）
    private String personName; // 联系人名称
    private String personPhone; // 联系电话
    private String planName; // 采购计划名称
    private String backgroundMemo; // 采购项目背景
    private String causeMemo; // 拟不进行招标原因
    private String otherMemo; // 其他需要说明的情况
    private String unOrdinaryBiddingName; // 拟邀请招标情形名称(一般招标）
    private String purchaseMemo; // 拟采用的采购方式
    private Integer billState; // 单据状态
    private Long projectId; // 项目Id
    private Long orgId; // 项目部Id
    private Long parentOrgId; // 项目部上级Id
    private Long employeeId; // 经办人
    private Long unLegalBidding; // 拟邀请招标情形（法定必招）
    private Long personId; // 联系人id
    private Long planId; // 采购计划单号
    private Long unOrdinaryBidding; // 拟邀请招标情形(一般招标）
    

    public BigDecimal getMatterTaxMny() {
        return matterTaxMny;
    }

    public void setMatterTaxMny(BigDecimal matterTaxMny) {
        this.matterTaxMny = matterTaxMny;
    }
    public BigDecimal getPreTaxMny() {
        return preTaxMny;
    }

    public void setPreTaxMny(BigDecimal preTaxMny) {
        this.preTaxMny = preTaxMny;
    }
    public Date getMakeDate() {
        return makeDate;
    }

    public void setMakeDate(Date makeDate) {
        this.makeDate = makeDate;
    }
    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }
    public String getParentOrgCode() {
        return parentOrgCode;
    }

    public void setParentOrgCode(String parentOrgCode) {
        this.parentOrgCode = parentOrgCode;
    }
    public String getAllOrgName() {
        return allOrgName;
    }

    public void setAllOrgName(String allOrgName) {
        this.allOrgName = allOrgName;
    }
    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    public String getTenderType() {
        return tenderType;
    }

    public void setTenderType(String tenderType) {
        this.tenderType = tenderType;
    }
    public String getPurchaseMatter() {
        return purchaseMatter;
    }

    public void setPurchaseMatter(String purchaseMatter) {
        this.purchaseMatter = purchaseMatter;
    }
    public String getUnLegalBiddingName() {
        return unLegalBiddingName;
    }

    public void setUnLegalBiddingName(String unLegalBiddingName) {
        this.unLegalBiddingName = unLegalBiddingName;
    }
    public String getPersonName() {
        return personName;
    }

    public void setPersonName(String personName) {
        this.personName = personName;
    }
    public String getPersonPhone() {
        return personPhone;
    }

    public void setPersonPhone(String personPhone) {
        this.personPhone = personPhone;
    }
    public String getPlanName() {
        return planName;
    }

    public void setPlanName(String planName) {
        this.planName = planName;
    }
    public String getBackgroundMemo() {
        return backgroundMemo;
    }

    public void setBackgroundMemo(String backgroundMemo) {
        this.backgroundMemo = backgroundMemo;
    }
    public String getCauseMemo() {
        return causeMemo;
    }

    public void setCauseMemo(String causeMemo) {
        this.causeMemo = causeMemo;
    }
    public String getOtherMemo() {
        return otherMemo;
    }

    public void setOtherMemo(String otherMemo) {
        this.otherMemo = otherMemo;
    }
    public String getUnOrdinaryBiddingName() {
        return unOrdinaryBiddingName;
    }

    public void setUnOrdinaryBiddingName(String unOrdinaryBiddingName) {
        this.unOrdinaryBiddingName = unOrdinaryBiddingName;
    }
    public String getPurchaseMemo() {
        return purchaseMemo;
    }

    public void setPurchaseMemo(String purchaseMemo) {
        this.purchaseMemo = purchaseMemo;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    @ReferSerialTransfer(referCode = "project-set")
    public Long getProjectId() {
        return projectId;
    }
    @ReferDeserialTransfer
    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }
    @ReferSerialTransfer(referCode = "idm-employee")
    public Long getEmployeeId() {
        return employeeId;
    }
    @ReferDeserialTransfer
    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
    @ReferSerialTransfer(referCode = "support-defdoc")
    public Long getUnLegalBidding() {
        return unLegalBidding;
    }
    @ReferDeserialTransfer
    public void setUnLegalBidding(Long unLegalBidding) {
        this.unLegalBidding = unLegalBidding;
    }
    @ReferSerialTransfer(referCode = "idm-employee")
    public Long getPersonId() {
        return personId;
    }
    @ReferDeserialTransfer
    public void setPersonId(Long personId) {
        this.personId = personId;
    }
    @ReferSerialTransfer(referCode = "purchase_plan_code")
    public Long getPlanId() {
        return planId;
    }
    @ReferDeserialTransfer
    public void setPlanId(Long planId) {
        this.planId = planId;
    }
    @ReferSerialTransfer(referCode = "support-defdoc")
    public Long getUnOrdinaryBidding() {
        return unOrdinaryBidding;
    }
    @ReferDeserialTransfer
    public void setUnOrdinaryBidding(Long unOrdinaryBidding) {
        this.unOrdinaryBidding = unOrdinaryBidding;
    }
    
}

==> ejc-procurement-api-3.0.0-20251204.114052-58-sources.jar: com/ejianc/business/procurement/plan/vo/UnTenderMatterVO.java <==
package com.ejianc.business.procurement.plan.vo;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;

import java.math.BigDecimal;
import java.util.Date;


/**
 * 拟不招标事项申请表
 * 
 * @author generator
 * 
 */
public class UnTenderMatterVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private BigDecimal matterTaxMny; // 各标的预算
    private BigDecimal preTaxMny; // 预计合同总金额
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date makeDate; // 编制日期
    private String billCode; // 单据编号
    private String projectCode; // 项目编码
    private String projectName; // 项目名称
    private String orgName; // 项目部名称
    private String orgCode; // 项目部编码
    private String parentOrgName; // 项目部上级名称
    private String parentOrgCode; // 项目部上级编码
    private String allOrgName; // 所属组织(所属单位-项目经理部)
    private String employeeName; // 经办人名称
    private String tenderType; // 招标执行程序1-法定必招项目，2-一般招标项目
    private String purchaseMatter; // 采购标的
    private String unLegalBiddingName; // 拟邀请招标情形名称（法定必招）
    private String personName; // 联系人名称
    private String personPhone; // 联系电话
    private String planName; // 采购计划名称
    private String backgroundMemo; // 采购项目背景
    private String causeMemo; // 拟不进行招标原因
    private String otherMemo; // 其他需要说明的情况
    private String unOrdinaryBiddingName; // 拟邀请招标情形名称(一般招标）
    private String purchaseMemo; // 拟采用的采购方式
    private Integer billState; // 单据状态
    private Long projectId; // 项目Id
    private Long orgId; // 项目部Id
    private Long parentOrgId; // 项目部上级Id
    private Long employeeId; // 经办人
    private Long unLegalBidding; // 拟邀请招标情形（法定必招）
    private Long personId; // 联系人id
    private Long planId; // 采购计划单号
    private Long unOrdinaryBidding; // 拟邀请招标情形(一般招标）
    private String businessType; // 标的物类别1-工程，2-货物，3-服务

    public String getBusinessType() {
        return businessType;
    }

    public void setBusinessType(String businessType) {
        this.businessType = businessType;
    }

    public BigDecimal getMatterTaxMny() {
        return matterTaxMny;
    }

    public void setMatterTaxMny(BigDecimal matterTaxMny) {
        this.matterTaxMny = matterTaxMny;
    }
    public BigDecimal getPreTaxMny() {
        return preTaxMny;
    }

    public void setPreTaxMny(BigDecimal preTaxMny) {
        this.preTaxMny = preTaxMny;
    }
    public Date getMakeDate() {
        return makeDate;
    }

    public void setMakeDate(Date makeDate) {
        this.makeDate = makeDate;
    }
    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }
    public String getParentOrgCode() {
        return parentOrgCode;
    }

    public void setParentOrgCode(String parentOrgCode) {
        this.parentOrgCode = parentOrgCode;
    }
    public String getAllOrgName() {
        return allOrgName;
    }

    public void setAllOrgName(String allOrgName) {
        this.allOrgName = allOrgName;
    }
    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    public String getTenderType() {
        return tenderType;
    }

    public void setTenderType(String tenderType) {
        this.tenderType = tenderType;
    }
    public String getPurchaseMatter() {
        return purchaseMatter;
    }

    public void setPurchaseMatter(String purchaseMatter) {
        this.purchaseMatter = purchaseMatter;
    }
    public String getUnLegalBiddingName() {
        return unLegalBiddingName;
    }

    public void setUnLegalBiddingName(String unLegalBiddingName) {
        this.unLegalBiddingName = unLegalBiddingName;
    }
    public String getPersonName() {
        return personName;
    }

    public void setPersonName(String personName) {
        this.personName = personName;
    }
    public String getPersonPhone() {
        return personPhone;
    }

    public void setPersonPhone(String personPhone) {
        this.personPhone = personPhone;
    }
    public String getPlanName() {
        return planName;
    }

    public void setPlanName(String planName) {
        this.planName = planName;
    }
    public String getBackgroundMemo() {
        return backgroundMemo;
    }

    public void setBackgroundMemo(String backgroundMemo) {
        this.backgroundMemo = backgroundMemo;
    }
    public String getCauseMemo() {
        return causeMemo;
    }

    public void setCauseMemo(String causeMemo) {
        this.causeMemo = causeMemo;
    }
    public String getOtherMemo() {
        return otherMemo;
    }

    public void setOtherMemo(String otherMemo) {
        this.otherMemo = otherMemo;
    }
    public String getUnOrdinaryBiddingName() {
        return unOrdinaryBiddingName;
    }

    public void setUnOrdinaryBiddingName(String unOrdinaryBiddingName) {
        this.unOrdinaryBiddingName = unOrdinaryBiddingName;
    }
    public String getPurchaseMemo() {
        return purchaseMemo;
    }

    public void setPurchaseMemo(String purchaseMemo) {
        this.purchaseMemo = purchaseMemo;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    @ReferSerialTransfer(referCode = "project-set")
    public Long getProjectId() {
        return projectId;
    }
    @ReferDeserialTransfer
    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }
    @ReferSerialTransfer(referCode = "idm-employee")
    public Long getEmployeeId() {
        return employeeId;
    }
    @ReferDeserialTransfer
    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
    @ReferSerialTransfer(referCode = "support-defdoc")
    public Long getUnLegalBidding() {
        return unLegalBidding;
    }
    @ReferDeserialTransfer
    public void setUnLegalBidding(Long unLegalBidding) {
        this.unLegalBidding = unLegalBidding;
    }
    @ReferSerialTransfer(referCode = "idm-employee")
    public Long getPersonId() {
        return personId;
    }
    @ReferDeserialTransfer
    public void setPersonId(Long personId) {
        this.personId = personId;
    }
    @ReferSerialTransfer(referCode = "purchase_plan_code")
    public Long getPlanId() {
        return planId;
    }
    @ReferDeserialTransfer
    public void setPlanId(Long planId) {
        this.planId = planId;
    }
    @ReferSerialTransfer(referCode = "support-defdoc")
    public Long getUnOrdinaryBidding() {
        return unOrdinaryBidding;
    }
    @ReferDeserialTransfer
    public void setUnOrdinaryBidding(Long unOrdinaryBidding) {
        this.unOrdinaryBidding = unOrdinaryBidding;
    }
    
}
